@@ -137,7 +137,7 @@ use warnings;
 
 use base qw{ Astro::Coord::ECI::TLE };
 
-our $VERSION = '0.104_01';
+our $VERSION = '0.104_02';
 
 use Astro::Coord::ECI::Utils 0.091 qw{:all};
 use Carp;
@@ -1681,7 +1681,7 @@ sub _set_operational_status {
 # All Iridium Classic satellites.
 #
 # Generated by Astro::SpaceTrack tools/all_iridium_classic -tle -indent=0
-# on Thu Aug 30 12:29:18 2018 GMT
+# on Sat Sep  1 14:50:05 2018 GMT
 
 __PACKAGE__->status( clear => 'iridium' );
 __PACKAGE__->status( add => 24792, iridium => 'D', 'Iridium 8', 'Decayed 2017-11-24' );
@@ -1735,7 +1735,7 @@ __PACKAGE__->status( add => 25108, iridium => 'D', 'Iridium 49', 'Decayed 2018-0
 __PACKAGE__->status( add => 25169, iridium => '+', 'Iridium 52', '' );
 __PACKAGE__->status( add => 25170, iridium => 'S', 'Iridium 56', '' );
 __PACKAGE__->status( add => 25171, iridium => '+', 'Iridium 54', '' );
-__PACKAGE__->status( add => 25172, iridium => '+', 'Iridium 50', '' );
+__PACKAGE__->status( add => 25172, iridium => 'S', 'Iridium 50', '' );
 __PACKAGE__->status( add => 25173, iridium => '+', 'Iridium 53', '' );
 __PACKAGE__->status( add => 25262, iridium => '-', 'Iridium 51', 'Tumbling' );
 __PACKAGE__->status( add => 25263, iridium => 'S', 'Iridium 61', '' );
@@ -1783,8 +1783,8 @@ __PACKAGE__->status( add => 27450, iridium => 'S', 'Iridium 97', '' );
 __PACKAGE__->status( add => 27451, iridium => 'D', 'Iridium 98', 'Decayed 2018-08-24' );
 
 # Summary:
-# Operational [+]: 15
-#       Spare [S]: 13
+# Operational [+]: 14
+#       Spare [S]: 14
 #    Tumbling [-]: 36
 #     Decayed [D]: 33
 
